//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[KokushiHoraHandPattern](index.md)/[thirteenWaiting](thirteen-waiting.md)

# thirteenWaiting

[common]\
val [thirteenWaiting](thirteen-waiting.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否十三面和牌
